==> cx88-1.4.2.tar.gz: cx88-1.4.2/client/drivers/hdtv_wonder.h <==
/*-
 * Copyright 2011 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __HDTV_WONDER_H__
#define __HDTV_WONDER_H__

#include <stdlib.h>
#include <unistd.h>
#include <sys/errno.h>
#include <iostream>
#include "tuv1236d.h"
#include "tda9887.h"
#include "nxt2004.h"
#include "cx88_debug.h"
#include "cx88_mpeg_driver.h"
#include "cx88_analog_driver.h"

namespace cx88_mpeg_driver_factory
{

   class hdtv_wonder
      : public cx88_mpeg_driver
   {
      public:
         
         hdtv_wonder(
            cx88_xml_config &cx88conf,
            tuner_config &tunerconf,
            const char *devnode,
            capvec &captures,
            int &error)
            : cx88_mpeg_driver(cx88conf, tunerconf, devnode, captures, error),
              m_tuner(NULL)
         {}

         virtual ~hdtv_wonder(void) {}

         virtual const char *get_name(void)
         {
            return "HDTV Wonder";
         }

         virtual uint32_t get_caps(void)
         {
            return CX88_MPEG_CAP_ATSC | CX88_MPEG_CAP_QAM;
         }

      protected:

         virtual int create_i2c_drivers(void)
         {
            int error = 0;
            m_i2c_devs[0].driver = m_tuner = new tuv1236d(m_tunerconf, *(m_i2c_devs[0].dev));
            m_i2c_devs[1].driver = new nxt2004(m_tunerconf, *(m_i2c_devs[1].dev), error);
            if ((m_i2c_devs[0].driver == NULL) || (m_i2c_devs[1].driver == NULL))
            {
               CX88ERR << "Error initializing tuner/demodulator driver for HDTV Wonder" << std::endl;
               return ENOMEM;
            }
            return error;
         }

         virtual int select_source(const char *name)
         {
            m_source_mask = CX88_SOURCE_DEFAULT;
            m_tuner->select_input(tuv1236d::TUNER_INPUT_DEFAULT);
            if (name != NULL)
            {
               if (strcasecmp(name, "Port 1") == 0)
               {
                  m_tuner->select_input(tuv1236d::TUNER_INPUT_1);
               }
               else if (strcasecmp(name, "Port 2") == 0)
               {
                  m_tuner->select_input(tuv1236d::TUNER_INPUT_2);
               }
            }
            return 0;
         }

         virtual void destroy_i2c_drivers(void)
         {
            delete m_i2c_devs[1].driver;
            delete m_i2c_devs[0].driver;  
         }
         
         virtual int create_i2c_devices(void)
         {
            m_i2c_devs[0].conf.in_addr = 0x61;
            m_i2c_devs[0].source_mask = CX88_SOURCE_DEFAULT;
            m_i2c_devs[1].conf.in_addr = 0x0A;
            m_i2c_devs[1].source_mask = CX88_SOURCE_DEFAULT;
            return 0;
         }

         tuv1236d *m_tuner;
   };
}

namespace cx88_analog_driver_factory
{
   class hdtv_wonder
      : public cx88_analog_driver
   {
      public:
         
         hdtv_wonder(
            cx88_xml_config &cx88conf,
            tuner_config &tunerconf,
            const char *devnode,
            capvec &captures,
            cx88_analog_mode mode,
            cx88_analog_driver *slave,
            cx88_analog_driver *pip_driver,
            int &error)
            : cx88_analog_driver(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error),
              m_tuner(NULL)
         {}
         
         virtual ~hdtv_wonder(void) {}

         virtual const char *get_name(void)
         {
            return "HDTV Wonder";
         }

         virtual uint32_t get_caps(void)
         {
            return CX88_ANALOG_CAP_TV | CX88_ANALOG_CAP_SVIDEO | CX88_ANALOG_CAP_COMPOSITE |
                   CX88_ANALOG_CAP_NTSC | CX88_ANALOG_CAP_TV_AUDIO |
                   CX88_ANALOG_CAP_MUTE;
         }

      protected:

         uint8_t m_input_mux;
         uint8_t m_input_type;
         tuv1236d *m_tuner;

         virtual int create_i2c_drivers(void)
         {
            int error = nxt2004::enable_tuner(*(m_i2c_devs[2].dev), nxt2004::TUNER_SOURCE_ANALOG);
            if (error)
            {
               CX88ERR << "Error enabling tuner for HDTV Wonder" << std::endl;
               return error;
            }
            m_i2c_devs[1].driver = new tda9887(m_tunerconf, *(m_i2c_devs[1].dev),
               TDA9887_OPTION_RADIO_IF_41_3 | TDA9887_OPTION_RADIO_GAIN_NORM);
            m_i2c_devs[0].driver = m_tuner = new tuv1236d(m_tunerconf, *(m_i2c_devs[0].dev));
            if ((m_i2c_devs[0].driver == NULL) || (m_i2c_devs[1].driver == NULL))
            {
               CX88ERR << "Error initializing tuner driver for HDTV Wonder" << std::endl;
               return ENOMEM;
            }
            return 0;
         }
         
         virtual void destroy_i2c_drivers(void)
         {
            delete m_i2c_devs[0].driver;
            delete m_i2c_devs[1].driver;
         }
         
         virtual int create_i2c_devices(void)
         {
            m_i2c_devs[0].conf.in_addr = 0x61;
            m_i2c_devs[0].source_mask = CX88_SOURCE_DEFAULT;
            m_i2c_devs[1].conf.in_addr = 0x43;
            m_i2c_devs[1].source_mask = CX88_SOURCE_DEFAULT;
            m_i2c_devs[2].conf.in_addr = 0x0A;
            return 0;
         }
         
         virtual int select_source(const char *name)
         {
            if (m_slave_mode)
            {
               return 0;
            }
            m_source_mask = CX88_SOURCE_DEFAULT;
            m_input_mux = CX88_VIDEO_INPUT_MUX1;
            m_input_type = CX88_VIDEO_INPUT_COMPOSITE;
            m_tuner->select_input(tuv1236d::TUNER_INPUT_DEFAULT);
            if (name != NULL)
            {
               if (strcasecmp(name, "Composite") == 0)
               {
                  m_source_mask = 0;
                  m_input_mux = CX88_VIDEO_INPUT_MUX2;
                  m_input_type = CX88_VIDEO_INPUT_COMPOSITE;
               }
               else if (strcasecmp(name, "S-Video") == 0)
               {
                  m_source_mask = 0;
                  m_input_mux = CX88_VIDEO_INPUT_MUX3;
                  m_input_type = CX88_VIDEO_INPUT_SVIDEO;
               }
               else if (strcasecmp(name, "Port 1") == 0)
               {
                  m_tuner->select_input(tuv1236d::TUNER_INPUT_1);
               }
               else if (strcasecmp(name, "Port 2") == 0)
               {
                  m_tuner->select_input(tuv1236d::TUNER_INPUT_2);
               }
            }
            return 0;
         }

         virtual int set_capture_options(cx88_video_capture &capture)
         {
            capture.in_input_source = m_input_mux;
            capture.in_input_type = m_input_type;
            return 0;
         }
   };
   
};
#endif

==> cx88-1.4.4.tar.gz: cx88-1.4.4/client/drivers/hdtv_wonder.h <==
/*-
 * Copyright 2011 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __HDTV_WONDER_H__
#define __HDTV_WONDER_H__

#include "tuv1236d.h"
#include "cx88_mpeg_driver.h"
#include "cx88_analog_driver.h"

namespace cx88_mpeg_driver_factory
{

   class hdtv_wonder
      : public cx88_mpeg_driver
   {
      public:
         
         hdtv_wonder(
            cx88_xml_config &cx88conf,
            tuner_config &tunerconf,
            const char *devnode,
            capvec &captures,
            int &error)
            : cx88_mpeg_driver(cx88conf, tunerconf, devnode, captures, error),
              m_tuner(NULL)
         {}

         virtual ~hdtv_wonder(void) {}

         virtual const char *get_name(void)
         {
            return "HDTV Wonder";
         }

         virtual uint32_t get_caps(void)
         {
            return CX88_MPEG_CAP_ATSC | CX88_MPEG_CAP_QAM;
         }

         virtual const cx88_source *get_sources(void)
         {
            return m_sources;
         }

      protected:

         static const uint32_t HDTV_WONDER_SOURCE_PORT1 = 1 << 1;
         static const uint32_t HDTV_WONDER_SOURCE_PORT2 = 1 << 2;
         static const cx88_source m_sources[4];

         virtual int create_i2c_drivers(void);

         virtual int select_source(uint32_t source_mask);

         virtual void destroy_i2c_drivers(void);

         virtual int create_i2c_devices(void);

         tuv1236d *m_tuner;
   };
}

namespace cx88_analog_driver_factory
{
   class hdtv_wonder
      : public cx88_analog_driver
   {
      public:
         
         hdtv_wonder(
            cx88_xml_config &cx88conf,
            tuner_config &tunerconf,
            const char *devnode,
            capvec &captures,
            cx88_analog_mode mode,
            cx88_analog_driver *slave,
            cx88_analog_driver *pip_driver,
            int &error)
            : cx88_analog_driver(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error),
              m_tuner(NULL)
         {}
         
         virtual ~hdtv_wonder(void) {}

         virtual const char *get_name(void)
         {
            return "HDTV Wonder";
         }

         virtual uint32_t get_caps(void)
         {
            return CX88_ANALOG_CAP_TV | CX88_ANALOG_CAP_SVIDEO | CX88_ANALOG_CAP_COMPOSITE |
                   CX88_ANALOG_CAP_NTSC | CX88_ANALOG_CAP_TV_AUDIO |
                   CX88_ANALOG_CAP_MUTE;
         }

         virtual const cx88_source *get_sources(void)
         {
            return m_sources;
         }

      protected:

         static const uint32_t HDTV_WONDER_SOURCE_PORT1 = CX88_SOURCE_DEFAULT;
         static const uint32_t HDTV_WONDER_SOURCE_PORT2 = 1 << 1;
         static const uint32_t HDTV_WONDER_SOURCE_SVIDEO = 1 << 2;
         static const uint32_t HDTV_WONDER_SOURCE_COMPOSITE = 1 << 3;
         static const cx88_source m_sources[5];

         uint8_t m_input_mux;
         uint8_t m_input_type;
         tuv1236d *m_tuner;

         virtual int create_i2c_drivers(void);

         virtual void destroy_i2c_drivers(void);

         virtual int create_i2c_devices(void);

         virtual int select_source(uint32_t source_mask);

         virtual int set_capture_options(cx88_video_capture &capture);
   };
   
};
#endif
